if status is-interactive
    # Commands to run in interactive sessions can go here
end

#                   __ _          __ _     _
#                  / _(_)        / _(_)   | |
#   ___ ___  _ __ | |_ _  __ _  | |_ _ ___| |__
#  / __/ _ \| '_ \|  _| |/ _` | |  _| / __| '_ \
# | (_| (_) | | | | | | | (_| |_| | | \__ \ | | |
#  \___\___/|_| |_|_| |_|\__, (_)_| |_|___/_| |_|
#                         __/ |
#                        |___/
#  _               ___  _ _
# | |             / _ \| | |
# | |__  _   _   / /_\ \ | | ___  _____  ____  __
# | '_ \| | | |  |  _  | | |/ _ \/ _ \ \/ /\ \/ /
# | |_) | |_| |  | | | | | |  __/  __/>  <  >  <
# |_.__/ \__, |  \_| |_/_|_|\___|\___/_/\_\/_/\_\
#         __/ |
#        |___/


#
# Environment-Variables
set fish_greeting
set toolbox "The following tools are active:

"
set warnings "The following packages are NOT active:

"

set -p EDITOR (which nvim)

## Set Distro-Packagemanager-Aliases

# DNF - Fedora
if command -v dnf
    alias install='sudo dnf install'
    alias update='sudo dnf update && sudo dnf upgrade'
    alias search='sudo dnf search'
    alias remove='sudo dnf remove'
    set -a ALIASSES "-- You're using DNF aliases!! --"
end

# APT/NALA - Debian
if command -v nala
    alias install='sudo nala update && sudo nala install'
    alias update='sudo nala update && sudo nala upgrade'
    alias search='nala search'
    alias remove='sudo nala remove'
    set ALIASSES "-- You're using NALA aliases!! --"
    else
if command -v apt
    alias install='sudo apt update && sudo apt install'
    alias update='sudo apt update && sudo apt upgrade'
    alias search='apt search'
    alias remove='sudo apt remove'
    set ALIASSES "-- You're using APT aliases!! --"
end
end

# Pacman - Arch
if command -v yay
    alias install='yay -S'
    alias update='yay -Syu'
    alias search='yay -Ss'
    alias remove='yay -R'
    set ALIASSES "-- You're using Arch!! - installed helper: yay --"
else
if command -v paru
    alias install='paru -S'
    alias update='paru -Syu'
    alias search='paru -Ss'
    alias remove='paru -R'
    set ALIASSES "-- You're using Arch!! - installed helper: paru --"
else
    if command -v pacman
    alias install='sudo pacman -S'
    alias update='sudo pacman -Syu'
    alias remove='sudo pacman -R'
    set ALIASSES "-- by the PACMAN - You're using Arch!! --"
end
end
end

# Zypper - OpenSuse
if command -v zypper
    alias install='sudo zypper in'
    alias update='sudo zypper dup'
    alias search='sudo zypper se'
    alias lock='sudo zypper al'
    alias remove='sudo zypper rm'    
    set ALIASSES "-- I see.. you're using OpenSUSE. i like <3 --
	ZYPPER   "
end

# APK - Alpine
if command -v apk
    alias install='sudo apk add'
    alias update='sudo apk update'
    alias search='sudo apk search'
    set ALIASSES "-- Alpine.. right, this fast os is evolving.. --"
end

## END Distro-Packagemanager-Aliases

# OMF - Oh-My-Fish
#if test -d "$HOME/.config/omf/"
#    omf update
#    alias rl='omf reload'
#    set -a fish_greed "Oh-my-FiSh installed and activated"
#end

#colorized ls
if command -v lsd
    alias ls='lsd -l'
    alias ll='pwd && lsd -lA && pwd'
    alias tree='lsd --tree'
    set -a toolbox "     using $(which lsd) for ls
    "
else
if command -v exa
    alias ls='exa --icons -l'
    alias ll='exa --icons -laa'
    alias tree='exa --icons -l -tree'
    set -a toolbox "     using $(which exa) for ls
    "
else
if command -v eza
    alias ls='eza --icons -l'
    alias ll='eza --icons -laa'
    alias tree='eza --icons -l -tree'
    set -a toolbox "     using $(which eza) for ls
    "
else
    alias ls='ls --color=always -lph'
    alias ll='ls --color=always -lAph'
    set -a toolbox "     using plain old ls, but with colors!!
    "
    set -a warnings "  no ls helper is installed [lsd, eza, exa..]
" 
end
end
end

#colored everything
alias ip="ip -c"
alias grep="grep --color=always"

#weather
alias www='curl wttr.in/Ulm'

#bat alias
if command -v batcat
    alias cat='batcat -p --paging=never'
    set -a toolbox " cat is using $(which batcat)
    "
else
if command -v bat
    alias cat='bat -p'
    set -a toolbox " cat is using $(which bat)
    "
	else
    set -a warnings "  bat
" 
end
end

if command -v tmux
    alias ts="tmux source $HOME/.tmux.conf"
    alias t="tmux"
    set -a toolbox " t is using $(which tmux)
    "
else
    set -a warnings "  tmux
" 
end


if command -v docker
    alias up='docker compose up'
    alias down='docker compose down'
    alias pull='docker compose pull'
    alias d='docker'
    alias dr='docker run --rm -it'
    alias ds='docker ps -a'
    alias dc='docker compose'
    alias appudpate='docker pull && docker compose up -d --force-recreate'
    set -a toolbox " d is using $(which docker) [docker]
    "
else 
    set -a warnings "  docker
" 
end

# z stands for Zoxide

if command -v zoxide
    zoxide init fish | source
    set -a toolbox " z is using $(which zoxide) [cd]
    "
else
    set -a warnings "  zoxide
" 
   end

# g stands for git
if command -v git
    alias g='git'
    alias gc='git clone'
    alias gs='git status'
    alias ga='git add'
    alias gcm='git commit'
    alias gp='git pull'
    set -a toolbox " g is using $(which git)
    "
else
    set -a warnings "  git
" 
end



#the *fetch's
if command -v pfetch
    alias clearl='command clear & pfetch && ls'
    alias p='pfetch'
    set -a toolbox " p is using $(which pfetch)
    "
else
    set -a warnings "  pfetch
    --> run 'git clone https://github.com/dylanaraps/pfetch.git && sudo cp pfetch/pfetch /bin/ && sudo rm -r pfetch/' to fix this
    "
end

if command -v neofetch
    alias nf='neofetch'
    alias clearnf='command clear & neofetch'
    set -a toolbox " nf is using $(which neofetch)
    "
end

#set nmap-alias
if command -v nmap
	alias scanvuln='sudo nmap --script vuln -vvv'
	alias sv='scanvuln'
	alias portscan='sudo nmap -sT'
	alias ps='portscan'
	set -a toolbox " nmap is using $(which nmap) [needs sudo]
	    sv |    'nmap --script vuln'	| vulnerabilityscan
	    ps |    'nmap -sT'			| portscanner
	"
end
#set colorscheme for bobthefish
if test -d $HOME/.config/fish/functions/
    set -g theme_nerd_fonts yes
    set -g defaults_user ($USER)
        # available options: dark, light, solarized(-dark/-light), base16(-dark/-light), zenburn, gruvbox(-light), dracula, nord, catppuccin-(latte/frappe/macchiato/mocha)
    set -g theme_color_scheme catppuccin-mocha
end    

set -a fish_greed "
$toolbox"

    alias code='codium'
    clear & pfetch
    alias clear='clear & pfetch && echo $toolbox'

echo "-------------------------------------------------------------"
echo $fish_greed
echo "-------------------------------------------------------------"
echo $ALIASSES
echo "-------------------------------------------------------------"
echo $warnings
